@@ -98,7 +98,7 @@ results, represented as a nested list.
 ``qubit_index``'th qubit in measurement operation ``key`` in the shot ``shot`` in the
 ``circuit_index``'th circuit of the batch.
 
-The results are nonnegative integers representing the computational basis state (for qubits, 0 or 1)
+The results are non-negative integers representing the computational basis state (for qubits, 0 or 1)
 that was the measurement outcome.
 
 ----
@@ -119,11 +119,11 @@ from uuid import UUID
 import requests
 from pydantic import BaseModel, Field
 
-REQUESTS_TIMEOUT = 10
+REQUESTS_TIMEOUT = 60
 
 DEFAULT_TIMEOUT_SECONDS = 900
-SECONDS_BETWEEN_CALLS = 1
-REFRESH_MARGIN_SECONDS = 5
+SECONDS_BETWEEN_CALLS = 3
+REFRESH_MARGIN_SECONDS = REQUESTS_TIMEOUT
 
 AUTH_CLIENT_ID = 'iqm_client'
 AUTH_REALM = 'cortex'
@@ -222,11 +222,13 @@ class RunRequest(BaseModel):
     """
     circuits: list[Circuit] = Field(..., description='batch of quantum circuit(s) to execute')
     'batch of quantum circuit(s) to execute'
-    settings: Optional[dict[str, Any]] = Field(
+    custom_settings: dict[str, Any] = Field(
         None,
-        description='IQM hardware settings and calibration data, or None to use the latest calibration set'
+        description='''Custom settings to overwrite default IQM hardware settings and calibration data.
+Note: This field should be always None in normal use.'''
     )
-    'IQM hardware settings and calibration data, or None to use the latest calibration set'
+    '''Custom settings to overwrite default IQM hardware settings and calibration data.
+Note: This field should be always None in normal use.'''
     calibration_set_id: Optional[int] = Field(
         None,
         description='ID of the calibration set to use, or None to use the latest calibration set'
@@ -262,6 +264,7 @@ class Metadata(BaseModel):
         None,
         description='ID of the calibration set used, or None if settings were specified'
     )
+    'ID of the calibration set used, or None if settings were specified'
 
 
 class RunResult(BaseModel):
@@ -510,7 +513,7 @@ class IQMClient:
             circuits: list[Circuit],
             *,
             qubit_mapping: Optional[dict[str, str]] = None,
-            settings: Optional[dict[str, Any]] = None,
+            custom_settings: Optional[dict[str, Any]] = None,
             calibration_set_id: Optional[int] = None,
             shots: int = 1,
     ) -> UUID:
@@ -521,7 +524,8 @@ class IQMClient:
             qubit_mapping: Mapping of human-readable (logical) qubit names in to physical qubit names.
                 Can be set to ``None`` if all ``circuits`` already use physical qubit names.
                 Note that the ``qubit_mapping`` is used for all ``circuits``.
-            settings: settings for the quantum computer
+            custom_settings: custom settings to overwrite default settings and calibration data.
+                Note: This field should be always None in normal use.
             calibration_set_id: ID of the calibration set to use instead of ``settings``
             shots: number of times ``circuit`` is executed
 
@@ -542,13 +546,6 @@ class IQMClient:
                 if diff:
                     raise ValueError(f'The qubits {diff} are not found in the provided qubit mapping.')
 
-            # check that all the physical qubit names in qubit_mapping are defined in the settings
-            if settings is not None:
-                physical_qubits = set(settings['subtrees'])  # pylint: disable=unsubscriptable-object
-                diff = target_qubits - physical_qubits
-                if diff:
-                    raise ValueError(f'The physical qubits {diff} in the qubit mapping are not defined in settings.')
-
             serialized_qubit_mapping = serialize_qubit_mapping(qubit_mapping)
 
         # ``bearer_token`` can be ``None`` if cocos we're connecting does not use authentication
@@ -557,7 +554,7 @@ class IQMClient:
         data = RunRequest(
             qubit_mapping=serialized_qubit_mapping,
             circuits=circuits,
-            settings=settings,
+            custom_settings=custom_settings,
             calibration_set_id=calibration_set_id,
             shots=shots
         )
