@@ -23,7 +23,7 @@ from iqm_client import (Circuit, ClientConfigurationError, IQMClient,
                         SingleQubitMapping, Status, serialize_qubit_mapping)
 from tests.conftest import MockJsonResponse, existing_run, missing_run
 
-REQUESTS_TIMEOUT = 10
+REQUESTS_TIMEOUT = 60
 
 
 def test_serialize_qubit_mapping():
@@ -35,7 +35,7 @@ def test_serialize_qubit_mapping():
     ]
 
 
-def test_submit_circuits_returns_id(mock_server, settings_dict, base_url, sample_circuit):
+def test_submit_circuits_returns_id(mock_server, base_url, sample_circuit):
     """
     Tests sending a circuit
     """
@@ -43,12 +43,26 @@ def test_submit_circuits_returns_id(mock_server, settings_dict, base_url, sample
     job_id = client.submit_circuits(
         circuits=[Circuit.parse_obj(sample_circuit)],
         qubit_mapping={'Qubit A': 'QB1', 'Qubit B': 'QB2'},
-        settings=settings_dict,
-        shots=1000)
+        shots=1000
+    )
     assert job_id == existing_run
 
 
-def test_submit_circuit_with_non_injective_qubit_mapping(mock_server, settings_dict, base_url, sample_circuit):
+def test_submit_circuits_with_custom_settings_returns_id(mock_server, settings_dict, base_url, sample_circuit):
+    """
+    Tests sending a circuit
+    """
+    client = IQMClient(base_url)
+    job_id = client.submit_circuits(
+        circuits=[Circuit.parse_obj(sample_circuit)],
+        custom_settings=settings_dict,
+        qubit_mapping={'Qubit A': 'QB1', 'Qubit B': 'QB2'},
+        shots=1000
+    )
+    assert job_id == existing_run
+
+
+def test_submit_circuit_with_non_injective_qubit_mapping(mock_server, base_url, sample_circuit):
     """
     Test non-injective qubit mapping.
     """
@@ -57,23 +71,10 @@ def test_submit_circuit_with_non_injective_qubit_mapping(mock_server, settings_d
         client.submit_circuits(
             circuits=[Circuit.parse_obj(sample_circuit)],
             qubit_mapping={'Qubit A': 'QB1', 'Qubit B': 'QB1'},
-            settings=settings_dict
         )
 
 
-def test_submit_circuit_with_non_existing_qubits(mock_server, settings_dict, base_url, sample_circuit):
-    """
-    Test qubit mapping containing a physical qubit name not present in the settings.
-    """
-    client = IQMClient(base_url)
-    with pytest.raises(ValueError, match="{'QB200'} in the qubit mapping are not defined in settings."):
-        client.submit_circuits(
-            circuits=[Circuit.parse_obj(sample_circuit)],
-            qubit_mapping={'Qubit A': 'QB1', 'Qubit B': 'QB200'},
-            settings=settings_dict)
-
-
-def test_submit_circuit_with_incomplete_qubit_mapping(mock_server, settings_dict, base_url, sample_circuit):
+def test_submit_circuit_with_incomplete_qubit_mapping(mock_server, base_url, sample_circuit):
     """
     Test the scenario when circuits contain qubit names that are not present in the provided qubit mapping.
     """
@@ -82,7 +83,7 @@ def test_submit_circuit_with_incomplete_qubit_mapping(mock_server, settings_dict
         client.submit_circuits(
             circuits=[Circuit.parse_obj(sample_circuit)],
             qubit_mapping={'Qubit A': 'QB1'},
-            settings=settings_dict)
+        )
 
 
 def test_submit_circuits_without_settings_returns_id(mock_server, base_url, sample_circuit):
@@ -93,7 +94,8 @@ def test_submit_circuits_without_settings_returns_id(mock_server, base_url, samp
     job_id = client.submit_circuits(
         qubit_mapping={'Qubit A': 'QB1', 'Qubit B': 'QB2'},
         circuits=[Circuit.parse_obj(sample_circuit)],
-        shots=1000)
+        shots=1000
+    )
     assert job_id == existing_run
 
 
@@ -106,23 +108,24 @@ def test_submit_circuits_with_calibration_set_id_returns_id(mock_server, base_ur
         qubit_mapping={'Qubit A': 'QB1', 'Qubit B': 'QB2'},
         circuits=[Circuit.parse_obj(sample_circuit)],
         calibration_set_id=calibration_set_id,
-        shots=1000)
+        shots=1000
+    )
     assert job_id == existing_run
 
 
-def test_submit_circuits_without_qubit_mapping_returns_id(mock_server, settings_dict, base_url, sample_circuit):
+def test_submit_circuits_without_qubit_mapping_returns_id(mock_server, base_url, sample_circuit):
     """
     Tests sending a circuit without qubit mapping
     """
     client = IQMClient(base_url)
     job_id = client.submit_circuits(
         circuits=[Circuit.parse_obj(sample_circuit)],
-        settings=settings_dict,
-        shots=1000)
+        shots=1000
+    )
     assert job_id == existing_run
 
 
-def test_get_run_status_and_results_for_existing_run(mock_server, base_url, settings_dict, calibration_set_id):
+def test_get_run_status_and_results_for_existing_run(mock_server, base_url, calibration_set_id):
     """
     Tests getting the run status
     """
@@ -134,7 +137,7 @@ def test_get_run_status_and_results_for_existing_run(mock_server, base_url, sett
     assert ready_run.metadata.calibration_set_id == calibration_set_id
 
 
-def test_get_run_status_for_existing_run(mock_server, base_url, settings_dict):
+def test_get_run_status_for_existing_run(mock_server, base_url):
     """
     Tests getting the run status
     """
@@ -144,7 +147,7 @@ def test_get_run_status_for_existing_run(mock_server, base_url, settings_dict):
     assert ready_run.status == Status.READY
 
 
-def test_get_run_status_and_results_for_missing_run(mock_server, base_url, settings_dict):
+def test_get_run_status_and_results_for_missing_run(mock_server, base_url):
     """
     Tests getting a task that was not created
     """
@@ -153,7 +156,7 @@ def test_get_run_status_and_results_for_missing_run(mock_server, base_url, setti
         assert client.get_run(missing_run)
 
 
-def test_get_run_status_for_missing_run(mock_server, base_url, settings_dict):
+def test_get_run_status_for_missing_run(mock_server, base_url):
     """
     Tests getting a task that was not created
     """
@@ -162,7 +165,7 @@ def test_get_run_status_for_missing_run(mock_server, base_url, settings_dict):
         assert client.get_run_status(missing_run)
 
 
-def test_waiting_for_results(mock_server, base_url, settings_dict):
+def test_waiting_for_results(mock_server, base_url):
     """
     Tests waiting for results for an existing task
     """
@@ -170,7 +173,7 @@ def test_waiting_for_results(mock_server, base_url, settings_dict):
     assert client.wait_for_results(existing_run).status == Status.READY
 
 
-def test_user_warning_is_emitted_when_warnings_in_response(base_url, settings_dict, capsys):
+def test_user_warning_is_emitted_when_warnings_in_response(base_url):
     client = IQMClient(base_url)
     msg = 'This is a warning msg'
     with when(requests).get(f'{base_url}/jobs/{existing_run}', headers=None, timeout=REQUESTS_TIMEOUT).thenReturn(
@@ -180,14 +183,14 @@ def test_user_warning_is_emitted_when_warnings_in_response(base_url, settings_di
             client.get_run(existing_run)
 
 
-def test_base_url_is_invalid(settings_dict):
+def test_base_url_is_invalid():
     invalid_base_url = 'https//example.com'
     with pytest.raises(ClientConfigurationError) as exc:
         IQMClient(invalid_base_url)
     assert f'The URL schema has to be http or https. Incorrect schema in URL: {invalid_base_url}' == str(exc.value)
 
 
-def test_tokens_file_not_found(settings_dict):
+def test_tokens_file_not_found():
     base_url = 'https://example.com'
     tokens_file = '/home/iqm/tokens.json'
     with pytest.raises(ClientConfigurationError) as exc:
@@ -195,7 +198,7 @@ def test_tokens_file_not_found(settings_dict):
     assert f'File not found: {tokens_file}' == str(exc.value)
 
 
-def test_tokens_and_credentials_combo_invalid(settings_dict, credentials):
+def test_tokens_and_credentials_combo_invalid(credentials):
     tokens_file = '/home/iqm/tokens.json'
     base_url = 'https://example.com'
     with pytest.raises(ClientConfigurationError) as exc:
